function [spect,freq] = fft_analysis(xweight,fs,fftopt,fftcalc)
%INPUTS:
% xweight... weighted input signal for which the fft is calculated
% fs... Sampling rate
% fftopt... fftopt = 1: octave band analysis is claculated, 
%           fftopt = 2: third octave band analysis is calculated
%           fftopt = 3: thwelfth octave band analysis is calculated
% fftcal... fftcalc = 1: a fft of xweight was already calculated, i.e yabs
%           already exists
%           fftcalc = 0: it exists no previous fft of xweight
%
%OUTPUTS:
% spect... Spectrum of the input signal, either in octave, third octave
%          or 1/12 octave band analysis
% freq... Frequency vector where the center frequency of the analyzed bands are stored

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Author: Rafael Philip LUDWIG, 2014
%%%% Contact: rafael.ludwig@student.tugraz.at
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function Description: Check if FFT was calculated already before, if not,
% derive FFT (y, yabs), if yes, load the old FFT (yabs), check which FFT 
% resolution is selected, Derive 1/1,1/3,or 1/12 octave band analysis by 
% finding the positions of the lower and upper cut-off frequencys of the 
% respective band in the vector f, find the corresponding positions in the 
% vector yabs (absolute values of FFT are stored there) and calculate the 
% mean values of yabs between the  positions of the lower and upper cut-off
% frequency
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if fftcalc == 0 % Check if fft was already determined    
%% fft of the input signal
lenxweight = length(xweight); % length of input signal

NFFT = 2^nextpow2(lenxweight); % Next power of 2 from length of x
y = fft(xweight,NFFT); % fft
f = fs/2*linspace(0,1,NFFT/2+1); % Frequency vector from 0 Hz to one half of the sampling rate, resolution is equal to the input signal length
f = round(f*10)/10; % Round the frequencys to 1/10

yabs = abs(y); % Absolute value of the spectrum

clear y;

fftcalc = 1;
assignin('base','fftcalc',fftcalc);
assignin('base','yabs',yabs);
assignin('base','f',f);


end

yabs = evalin('base','yabs');
f = evalin('base','f');

%% Octave band analysis
if fftopt == 1 
    
    spect = zeros(1,10);
    
    f1_31_5 = find(f == 22, 1, 'first'); % Find the position of the lower cut off frequency of the first octave band in the vector f
    f2_31_5 = find(f == 44, 1, 'last'); % Find the position of the upper cut off frequency of the first octave band in the vector f
    spect(1) = mean(yabs(f1_31_5:f2_31_5)); % Derive the mean value of the spectrum for the values between lower and upper cut off frequency

    f1_63 = find(f == 44, 1, 'first');
    f2_63 = find(f == 88, 1, 'last');
    spect(2) = mean(yabs(f1_63:f2_63));

    f1_125 = find(f == 88, 1, 'first');
    f2_125 = find(f == 177, 1, 'last');
    spect(3) = mean(yabs(f1_125:f2_125));

    f1_250 = find(f == 177, 1, 'first');
    f2_250 = find(f == 355, 1, 'last');
    spect(4) = mean(yabs(f1_250:f2_250));

    f1_500 = find(f == 355, 1, 'first');
    f2_500 = find(f == 710, 1, 'last');
    spect(5) = mean(yabs(f1_500:f2_500));

    f1_1000 = find(f == 710, 1, 'first');
    f2_1000 = find(f == 1420, 1, 'last');
    spect(6) = mean(yabs(f1_1000:f2_1000));

    f1_2000 = find(f == 1420, 1, 'first');
    f2_2000 = find(f == 2840, 1, 'last');
    spect(7) = mean(yabs(f1_2000:f2_2000));

    f1_4000 = find(f == 2840, 1, 'first');
    f2_4000 = find(f == 5680, 1, 'last');
    spect(8) = mean(yabs(f1_4000:f2_4000));

    f1_8000 = find(f == 5680, 1, 'first');
    f2_8000 = find(f == 11360, 1, 'last');
    spect(9) = mean(yabs(f1_8000:f2_8000));

    f1_16000 = find(f == 11360, 1, 'first');
    f2_16000 = length(f);
    spect(10) = mean(yabs(f1_16000:f2_16000));
    
    freq = [31.5 63 125 250 500 1000 2000 4000 8000 16000]; % Store the evaluated octave bands in a vector 

%% 1/3 octave band analysis 
elseif fftopt == 2   
    
    spect = zeros(1,30);
    
    f1_25 = find(f == 22.4, 1, 'first'); % Find the position of the lower cut off frequency of the first third octave band in the vector f
    f2_25 = find(f == 28.2, 1, 'last'); % Find the position of the upper cut off frequency of the first third octave band in the vector f
    spect(1) = mean(yabs(f1_25:f2_25)); % Derive the mean value of the spectrum for the values between lower and upper cut off frequency
    
    f1_31_5 = find(f == 28.2, 1, 'first');
    f2_31_5 = find(f == 35.5, 1, 'last');
    spect(2) = mean(yabs(f1_31_5:f2_31_5));
    
    f1_40 = find(f == 35.5, 1, 'first');
    f2_40 = find(f == 44.7, 1, 'last');
    spect(3) = mean(yabs(f1_40:f2_40));
    
    f1_50 = find(f == 44.7, 1, 'first');
    f2_50 = find(f == 56.2, 1, 'last');
    spect(4) = mean(yabs(f1_50:f2_50));
    
    f1_63 = find(f == 56.2, 1, 'first');
    f2_63 = find(f == 70.8, 1, 'last');
    spect(5) = mean(yabs(f1_63:f2_63));
    
    f1_80 = find(f == 70.8, 1, 'first');
    f2_80 = find(f == 89.1, 1, 'last');
    spect(6) = mean(yabs(f1_80:f2_80));
    
    f1_100 = find(f == 89.1, 1, 'first');
    f2_100 = find(f == 112, 1, 'last');
    spect(7) = mean(yabs(f1_100:f2_100));

    f1_125 = find(f == 112, 1, 'first');
    f2_125 = find(f == 141, 1, 'last');
    spect(8) = mean(yabs(f1_125:f2_125));
    
    f1_160 = find(f == 141, 1, 'first');
    f2_160 = find(f == 178, 1, 'last');
    spect(9) = mean(yabs(f1_160:f2_160));
    
    f1_200 = find(f == 178, 1, 'first');
    f2_200 = find(f == 224, 1, 'last');
    spect(10) = mean(yabs(f1_200:f2_200));
    
    f1_250 = find(f == 224, 1, 'first');
    f2_250 = find(f == 282, 1, 'last');
    spect(11) = mean(yabs(f1_250:f2_250));

    f1_315 = find(f == 282, 1, 'first');
    f2_315 = find(f == 355, 1, 'last');
    spect(12) = mean(yabs(f1_315:f2_315));
    
    f1_400 = find(f == 355, 1, 'first');
    f2_400 = find(f == 447, 1, 'last');
    spect(13) = mean(yabs(f1_400:f2_400));
    
    f1_500 = find(f == 447, 1, 'first');
    f2_500 = find(f == 562, 1, 'last');
    spect(14) = mean(yabs(f1_500:f2_500));
    
    f1_630 = find(f == 562, 1, 'first');
    f2_630 = find(f == 708, 1, 'last');
    spect(15) = mean(yabs(f1_630:f2_630));
    
    f1_800 = find(f == 708, 1, 'first');
    f2_800 = find(f == 891, 1, 'last');
    spect(16) = mean(yabs(f1_800:f2_800));
    
    f1_1000 = find(f == 891, 1, 'first');
    f2_1000 = find(f == 1122, 1, 'last');
    spect(17) = mean(yabs(f1_1000:f2_1000));
    
    f1_1250 = find(f == 1122, 1, 'first');
    f2_1250 = find(f == 1413, 1, 'last');
    spect(18) = mean(yabs(f1_1250:f2_1250));
    
    f1_1600 = find(f == 1413, 1, 'first');
    f2_1600 = find(f == 1778, 1, 'last');
    spect(19) = mean(yabs(f1_1600:f2_1600));
    
    f1_2000 = find(f == 1778, 1, 'first');
    f2_2000 = find(f == 2239, 1, 'last');
    spect(20) = mean(yabs(f1_2000:f2_2000));
    
    f1_2500 = find(f == 2239, 1, 'first');
    f2_2500 = find(f == 2818, 1, 'last');
    spect(21) = mean(yabs(f1_2500:f2_2500));
    
    f1_3150 = find(f == 2818, 1, 'first');
    f2_3150 = find(f == 3548, 1, 'last');
    spect(22) = mean(yabs(f1_3150:f2_3150));
    
    f1_4000 = find(f == 3548, 1, 'first');
    f2_4000 = find(f == 4467, 1, 'last');
    spect(23) = mean(yabs(f1_4000:f2_4000));
    
    f1_5000 = find(f == 4467, 1, 'first');
    f2_5000 = find(f == 5623, 1, 'last');
    spect(24) = mean(yabs(f1_5000:f2_5000));
    
    f1_6300 = find(f == 5623, 1, 'first');
    f2_6300 = find(f == 7079, 1, 'last');
    spect(25) = mean(yabs(f1_6300:f2_6300));
    
    f1_8000 = find(f == 7079, 1, 'first');
    f2_8000 = find(f == 8913, 1, 'last');
    spect(26) = mean(yabs(f1_8000:f2_8000));
    
    f1_10000 = find(f == 8913, 1, 'first');
    f2_10000 = find(f == 11220, 1, 'last');
    spect(27) = mean(yabs(f1_10000:f2_10000));

    f1_12500 = find(f == 11220, 1, 'first');
    f2_12500 = find(f == 14130, 1, 'last');
    spect(28) = mean(yabs(f1_12500:f2_12500));
    
    f1_16000 = find(f == 14130, 1, 'first');
    f2_16000 = find(f == 17780, 1, 'last');
    spect(29) = mean(yabs(f1_16000:f2_16000));
    
    f1_20000 = find(f == 17780, 1, 'first');
    f2_20000 = length(f);
    spect(30) = mean(yabs(f1_20000:f2_20000));
    
    freq = [25 31.5 40 50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000 12500 16000 20000]; % Store the evaluated octave bands in a vector

%% 1/12 octave band analysis
else
    
    spect = zeros(1,120);
    
    % 1st octave
    f1_22_7 = find(f == 22.0, 1, 'first'); % Find the position of the lower cut off frequency of the first third octave band in the vector f
    f2_22_7 = find(f == 23.3, 1, 'last'); % Find the position of the upper cut off frequency of the first third octave band in the vector f
    spect(1) = mean(yabs(f1_22_7:f2_22_7)); % Derive the mean value of the spectrum for the values between lower and upper cut off frequency
    
    f1_24 = find(f == 23.3, 1, 'first');
    f2_24 = find(f == 24.7, 1, 'last');
    spect(2) = mean(yabs(f1_24:f2_24));
    
    f1_25_4 = find(f == 24.7, 1, 'first');
    f2_25_4 = find(f == 26.2, 1, 'last');
    spect(3) = mean(yabs(f1_25_4:f2_25_4));
    
    f1_26_9 = find(f == 26.2, 1, 'first');
    f2_26_9 = find(f == 27.7, 1, 'last');
    spect(4) = mean(yabs(f1_26_9:f2_26_9));
    
    f1_28_5 = find(f == 27.7, 1, 'first');
    f2_28_5 = find(f == 29.4, 1, 'last');
    spect(5) = mean(yabs(f1_28_5:f2_28_5));
    
    f1_30_2 = find(f == 29.4, 1, 'first');
    f2_30_2 = find(f == 31.1, 1, 'last');
    spect(6) = mean(yabs(f1_30_2:f2_30_2));
    
    f1_32 = find(f == 31.1, 1, 'first');
    f2_32 = find(f == 33, 1, 'last');
    spect(7) = mean(yabs(f1_32:f2_32));

    f1_34 = find(f == 33.0, 1, 'first');
    f2_34 = find(f == 34.9, 1, 'last');
    spect(8) = mean(yabs(f1_34:f2_34));
    
    f1_36 = find(f == 34.9, 1, 'first');
    f2_36 = find(f == 37.0, 1, 'last');
    spect(9) = mean(yabs(f1_36:f2_36));
    
    f1_38_1 = find(f == 37, 1, 'first');
    f2_38_1 = find(f == 39.2, 1, 'last');
    spect(10) = mean(yabs(f1_38_1:f2_38_1));
    
    f1_40_4 = find(f == 39.2, 1, 'first');
    f2_40_4 = find(f == 41.6, 1, 'last');
    spect(11) = mean(yabs(f1_40_4:f2_40_4));

    f1_42_8 = find(f == 41.6, 1, 'first');
    f2_42_8 = find(f == 44, 1, 'last');
    spect(12) = mean(yabs(f1_42_8:f2_42_8));
    
    % 2nd ocatve 
    f1_45_3 = find(f == 44, 1, 'first');
    f2_45_3 = find(f == 46.7, 1, 'last');
    spect(13) = mean(yabs(f1_45_3:f2_45_3));
    
    f1_48 = find(f == 46.7, 1, 'first');
    f2_48 = find(f == 49.4, 1, 'last');
    spect(14) = mean(yabs(f1_48:f2_48));
    
    f1_50_9 = find(f == 49.4, 1, 'first');
    f2_50_9 = find(f == 52.4, 1, 'last');
    spect(15) = mean(yabs(f1_50_9:f2_50_9));
    
    f1_53_9 = find(f == 52.4, 1, 'first');
    f2_53_9 = find(f == 55.5, 1, 'last');
    spect(16) = mean(yabs(f1_53_9:f2_53_9));
    
    f1_57_1 = find(f == 55.5, 1, 'first');
    f2_57_1 = find(f == 58.8, 1, 'last');
    spect(17) = mean(yabs(f1_57_1:f2_57_1));
    
    f1_60_5 = find(f == 58.8, 1, 'first');
    f2_60_5 = find(f == 62.3, 1, 'last');
    spect(18) = mean(yabs(f1_60_5:f2_60_5));
    
    f1_64_1 = find(f == 62.3, 1, 'first');
    f2_64_1 = find(f == 66.0, 1, 'last');
    spect(19) = mean(yabs(f1_64_1:f2_64_1));
    
    f1_68 = find(f == 66.0, 1, 'first');
    f2_68 = find(f == 69.9, 1, 'last');
    spect(20) = mean(yabs(f1_68:f2_68));
    
    f1_72 = find(f == 69.9, 1, 'first');
    f2_72 = find(f == 74.1, 1, 'last');
    spect(21) = mean(yabs(f1_72:f2_72));
    
    f1_76_3 = find(f == 74.1, 1, 'first');
    f2_76_3 = find(f == 78.5, 1, 'last');
    spect(22) = mean(yabs(f1_76_3:f2_76_3));
    
    f1_80_8 = find(f == 78.5, 1, 'first');
    f2_80_8 = find(f == 83.2, 1, 'last');
    spect(23) = mean(yabs(f1_80_8:f2_80_8));
    
    f1_85_6 = find(f == 83.2, 1, 'first');
    f2_85_6 = find(f == 88.1, 1, 'last');
    spect(24) = mean(yabs(f1_85_6:f2_85_6));
    
    % 3rd octave
    f1_90_7 = find(f == 88.1, 1, 'first');
    f2_90_7 = find(f == 93.4, 1, 'last');
    spect(25) = mean(yabs(f1_90_7:f2_90_7));
    
    f1_96_1 = find(f == 93.4, 1, 'first');
    f2_96_1 = find(f == 98.9, 1, 'last');
    spect(26) = mean(yabs(f1_96_1:f2_96_1));
    
    f1_102 = find(f == 98.9, 1, 'first');
    f2_102 = find(f == 105, 1, 'last');
    spect(27) = mean(yabs(f1_102:f2_102));

    f1_108 = find(f == 105, 1, 'first');
    f2_108 = find(f == 111, 1, 'last');
    spect(28) = mean(yabs(f1_108:f2_108));
    
    f1_114 = find(f == 111, 1, 'first');
    f2_114 = find(f == 118, 1, 'last');
    spect(29) = mean(yabs(f1_114:f2_114));
    
    f1_121 = find(f == 118, 1, 'first');
    f2_121 = find(f == 125, 1, 'last');
    spect(30) = mean(yabs(f1_121:f2_121));
    
    f1_128 = find(f == 125, 1, 'first'); 
    f2_128 = find(f == 132, 1, 'last'); 
    spect(31) = mean(yabs(f1_128:f2_128)); 
    
    f1_136 = find(f == 132, 1, 'first');
    f2_136 = find(f == 140, 1, 'last');
    spect(32) = mean(yabs(f1_136:f2_136));
    
    f1_144 = find(f == 140, 1, 'first');
    f2_144 = find(f == 148, 1, 'last');
    spect(33) = mean(yabs(f1_144:f2_144));
    
    f1_153 = find(f == 148, 1, 'first');
    f2_153 = find(f == 157, 1, 'last');
    spect(34) = mean(yabs(f1_153:f2_153));
    
    f1_162 = find(f == 157, 1, 'first');
    f2_162 = find(f == 167, 1, 'last');
    spect(35) = mean(yabs(f1_162:f2_162));
    
    f1_171 = find(f == 167, 1, 'first');
    f2_171 = find(f == 176, 1, 'last');
    spect(36) = mean(yabs(f1_171:f2_171));
    
    % 4th octave
    f1_182 = find(f == 176, 1, 'first');
    f2_182 = find(f == 187, 1, 'last');
    spect(37) = mean(yabs(f1_182:f2_182));

    f1_192 = find(f == 187, 1, 'first');
    f2_192 = find(f == 198, 1, 'last');
    spect(38) = mean(yabs(f1_192:f2_192));
    
    f1_204 = find(f == 198, 1, 'first');
    f2_204 = find(f == 210, 1, 'last');
    spect(39) = mean(yabs(f1_204:f2_204));
    
    f1_216 = find(f == 210, 1, 'first');
    f2_216 = find(f == 222, 1, 'last');
    spect(40) = mean(yabs(f1_216:f2_216));
    
    f1_229 = find(f == 222, 1, 'first');
    f2_229 = find(f == 236, 1, 'last');
    spect(41) = mean(yabs(f1_229:f2_229));

    f1_243 = find(f == 236, 1, 'first');
    f2_243 = find(f == 250, 1, 'last');
    spect(42) = mean(yabs(f1_243:f2_243));
    
    f1_257 = find(f == 250, 1, 'first');
    f2_257 = find(f == 264, 1, 'last');
    spect(43) = mean(yabs(f1_257:f2_257));
    
    f1_272 = find(f == 264, 1, 'first');
    f2_272 = find(f == 280, 1, 'last');
    spect(44) = mean(yabs(f1_272:f2_272));
    
    f1_288 = find(f == 280, 1, 'first');
    f2_288 = find(f == 297, 1, 'last');
    spect(45) = mean(yabs(f1_288:f2_288));
    
    f1_306 = find(f == 297, 1, 'first');
    f2_306 = find(f == 314, 1, 'last');
    spect(46) = mean(yabs(f1_306:f2_306));
    
    f1_324 = find(f == 314, 1, 'first');
    f2_324 = find(f == 333, 1, 'last');
    spect(47) = mean(yabs(f1_324:f2_324));
    
    f1_343 = find(f == 333, 1, 'first');
    f2_343 = find(f == 353, 1, 'last');
    spect(48) = mean(yabs(f1_343:f2_343));
    
    % 5th octave
    f1_364 = find(f == 353, 1, 'first');
    f2_364 = find(f == 374, 1, 'last');
    spect(49) = mean(yabs(f1_364:f2_364));
    
    f1_385 = find(f == 374, 1, 'first');
    f2_385 = find(f == 396, 1, 'last');
    spect(50) = mean(yabs(f1_385:f2_385));
    
    f1_408 = find(f == 396, 1, 'first');
    f2_408 = find(f == 420, 1, 'last');
    spect(51) = mean(yabs(f1_408:f2_408));
    
    f1_432 = find(f == 420, 1, 'first');
    f2_432 = find(f == 445, 1, 'last');
    spect(52) = mean(yabs(f1_432:f2_432));
    
    f1_458 = find(f == 445, 1, 'first');
    f2_458 = find(f == 471, 1, 'last');
    spect(53) = mean(yabs(f1_458:f2_458));
    
    f1_485 = find(f == 471, 1, 'first');
    f2_485 = find(f == 499, 1, 'last');
    spect(54) = mean(yabs(f1_485:f2_485));
    
    f1_514 = find(f == 499, 1, 'first');
    f2_514 = find(f == 529, 1, 'last');
    spect(55) = mean(yabs(f1_514:f2_514));
    
    f1_545 = find(f == 529, 1, 'first');
    f2_545 = find(f == 561, 1, 'last');
    spect(56) = mean(yabs(f1_545:f2_545));
    
    f1_577 = find(f == 561, 1, 'first');
    f2_577 = find(f == 594, 1, 'last');
    spect(57) = mean(yabs(f1_577:f2_577));

    f1_612 = find(f == 594, 1, 'first');
    f2_612 = find(f == 629, 1, 'last');
    spect(58) = mean(yabs(f1_612:f2_612));
    
    f1_648 = find(f == 629, 1, 'first');
    f2_648 = find(f == 667, 1, 'last');
    spect(59) = mean(yabs(f1_648:f2_648));
    
    f1_687 = find(f == 667, 1, 'first');
    f2_687 = find(f == 706, 1, 'last');
    spect(60) = mean(yabs(f1_687:f2_687));
    
    % 6th octave
    f1_727 = find(f == 706, 1, 'first'); 
    f2_727 = find(f == 749, 1, 'last'); 
    spect(61) = mean(yabs(f1_727:f2_727)); 
    
    f1_771 = find(f == 749, 1, 'first');
    f2_771 = find(f == 793, 1,'last');
    spect(62) = mean(yabs(f1_771:f2_771));
    
    f1_817 = find(f == 793, 1, 'first');
    f2_817 = find(f == 840, 1, 'last');
    spect(63) = mean(yabs(f1_817:f2_817));
    
    f1_865 = find(f == 840, 1, 'first');
    f2_865 = find(f == 890, 1, 'last');
    spect(64) = mean(yabs(f1_865:f2_865));
    
    f1_917 = find(f == 890, 1, 'first');
    f2_917 = find(f == 943, 1, 'last');
    spect(65) = mean(yabs(f1_917:f2_917));
    
    f1_971 = find(f == 943, 1, 'first');
    f2_971 = find(f == 999, 1, 'last');
    spect(66) = mean(yabs(f1_971:f2_971));
    
    f1_1029 = find(f == 999, 1, 'first');
    f2_1029 = find(f == 1059, 1, 'last');
    spect(67) = mean(yabs(f1_1029:f2_1029));

    f1_1090 = find(f == 1059, 1, 'first');
    f2_1090 = find(f == 1122, 1, 'last');
    spect(68) = mean(yabs(f1_1090:f2_1090));
    
    f1_1155 = find(f == 1122, 1, 'first');
    f2_1155 = find(f == 1189, 1, 'last');
    spect(69) = mean(yabs(f1_1155:f2_1155));
    
    f1_1224 = find(f == 1189, 1, 'first');
    f2_1224 = find(f == 1259, 1, 'last');
    spect(70) = mean(yabs(f1_1224:f2_1224));
    
    f1_1297 = find(f == 1259, 1, 'first');
    f2_1297 = find(f == 1334, 1, 'last');
    spect(71) = mean(yabs(f1_1297:f2_1297));

    f1_1374 = find(f == 1334, 1, 'first');
    f2_1374 = find(f == 1414, 1, 'last');
    spect(72) = mean(yabs(f1_1374:f2_1374));
    
    % 7th ocatve 
    f1_1456 = find(f == 1414, 1, 'first');
    f2_1456 = find(f == 1498, 1, 'last');
    spect(73) = mean(yabs(f1_1456:f2_1456));
    
    f1_1543 = find(f == 1498, 1, 'first');
    f2_1543 = find(f == 1587, 1, 'last');
    spect(74) = mean(yabs(f1_1543:f2_1543));
    
    f1_1634 = find(f == 1587, 1, 'first');
    f2_1634 = find(f == 1682, 1, 'last');
    spect(75) = mean(yabs(f1_1634:f2_1634));
    
    f1_1732 = find(f == 1682, 1, 'first');
    f2_1732 = find(f == 1782, 1, 'last');
    spect(76) = mean(yabs(f1_1732:f2_1732));
    
    f1_1835 = find(f == 1782, 1, 'first');
    f2_1835 = find(f == 1888, 1, 'last');
    spect(77) = mean(yabs(f1_1835:f2_1835));
    
    f1_1944 = find(f == 1888, 1, 'first');
    f2_1944 = find(f == 2000, 1, 'last');
    spect(78) = mean(yabs(f1_1944:f2_1944));
    
    f1_2060 = find(f == 2000, 1, 'first');
    f2_2060 = find(f == 2119, 1, 'last');
    spect(79) = mean(yabs(f1_2060:f2_2060));
    
    f1_2182 = find(f == 2119, 1, 'first');
    f2_2182 = find(f == 2245, 1, 'last');
    spect(80) = mean(yabs(f1_2182:f2_2182));
    
    f1_2312 = find(f == 2245, 1, 'first');
    f2_2312 = find(f == 2379, 1, 'last');
    spect(81) = mean(yabs(f1_2312:f2_2312));
    
    f1_2450 = find(f == 2379, 1, 'first');
    f2_2450 = find(f == 2521, 1, 'last');
    spect(82) = mean(yabs(f1_2450:f2_2450));
    
    f1_2596 = find(f == 2521, 1, 'first');
    f2_2596 = find(f == 2671, 1, 'last');
    spect(83) = mean(yabs(f1_2596:f2_2596));
    
    f1_2750 = find(f == 2671, 1, 'first');
    f2_2750 = find(f == 2830, 1, 'last');
    spect(84) = mean(yabs(f1_2750:f2_2750));
    
    % 8th octave
    f1_2914 = find(f == 2830, 1, 'first');
    f2_2914 = find(f == 2998, 1, 'last');
    spect(85) = mean(yabs(f1_2914:f2_2914));
    
    f1_3087 = find(f == 2998, 1, 'first');
    f2_3087 = find(f == 3177, 1, 'last');
    spect(86) = mean(yabs(f1_3087:f2_3087));
    
    f1_3271 = find(f == 3177, 1, 'first');
    f2_3271 = find(f == 3366, 1, 'last');
    spect(87) = mean(yabs(f1_3271:f2_3271));

    f1_3466 = find(f == 3366, 1, 'first');
    f2_3466 = find(f == 3566, 1, 'last');
    spect(88) = mean(yabs(f1_3466:f2_3466));
    
    f1_3672 = find(f == 3566, 1, 'first');
    f2_3672 = find(f == 3778, 1, 'last');
    spect(89) = mean(yabs(f1_3672:f2_3672));
    
    f1_3891 = find(f == 3778, 1, 'first');
    f2_3891 = find(f == 4003, 1, 'last');
    spect(90) = mean(yabs(f1_3891:f2_3891));
    
    f1_4122 = find(f == 4003, 1, 'first'); 
    f2_4122 = find(f == 4241, 1, 'last'); 
    spect(91) = mean(yabs(f1_4122:f2_4122)); 
    
    f1_4368 = find(f == 4241, 1, 'first');
    f2_4368 = find(f == 4494, 1, 'last');
    spect(92) = mean(yabs(f1_4368:f2_4368));
    
    f1_4628 = find(f == 4494, 1, 'first');
    f2_4628 = find(f == 4761, 1, 'last');
    spect(93) = mean(yabs(f1_4628:f2_4628));
    
    f1_4903 = find(f == 4761, 1, 'first');
    f2_4903 = find(f == 5045, 1, 'last');
    spect(94) = mean(yabs(f1_4903:f2_4903));
    
    f1_5195 = find(f == 5045, 1, 'first');
    f2_5195 = find(f == 5345, 1, 'last');
    spect(95) = mean(yabs(f1_5195:f2_5195));
    
    f1_5504 = find(f == 5345, 1, 'first');
    f2_5504 = find(f == 5663, 1, 'last');
    spect(96) = mean(yabs(f1_5504:f2_5504));
    
    % 9th octave
    f1_5832 = find(f == 5663, 1, 'first');
    f2_5832 = find(f == 6000, 1, 'last');
    spect(97) = mean(yabs(f1_5832:f2_5832));

    f1_6179 = find(f == 6000, 1, 'first');
    f2_6179 = find(f == 6357, 1, 'last');
    spect(98) = mean(yabs(f1_6179:f2_6179));
    
    f1_6547 = find(f == 6357, 1, 'first');
    f2_6547 = find(f == 6736, 1, 'last');
    spect(99) = mean(yabs(f1_6547:f2_6547));
    
    f1_6936 = find(f == 6736, 1, 'first');
    f2_6936 = find(f == 7137, 1, 'last');
    spect(100) = mean(yabs(f1_6936:f2_6936));
    
    f1_7349 = find(f == 7137, 1, 'first');
    f2_7349 = find(f == 7562, 1, 'last');
    spect(101) = mean(yabs(f1_7349:f2_7349));

    f1_7787 = find(f == 7562, 1, 'first');
    f2_7787 = find(f == 8012, 1, 'last');
    spect(102) = mean(yabs(f1_7787:f2_7787));
    
    f1_8250 = find(f == 8012, 1, 'first');
    f2_8250 = find(f == 8488, 1, 'last');
    spect(103) = mean(yabs(f1_8250:f2_8250));
    
    f1_8741 = find(f == 8488, 1, 'first');
    f2_8741 = find(f == 8994, 1, 'last');
    spect(104) = mean(yabs(f1_8741:f2_8741));
    
    f1_9261 = find(f == 8994, 1, 'first');
    f2_9261 = find(f == 9529, 1, 'last');
    spect(105) = mean(yabs(f1_9261:f2_9261));
    
    f1_9813 = find(f == 9529, 1, 'first');
    f2_9813 = find(f == 10096, 1, 'last');
    spect(106) = mean(yabs(f1_9813:f2_9813));
    
    f1_10397 = find(f == 10096, 1, 'first');
    f2_10397 = find(f == 10697, 1, 'last');
    spect(107) = mean(yabs(f1_10397:f2_10397));
    
    f1_11016 = find(f == 10697, 1, 'first');
    f2_11016 = find(f == 11334, 1, 'last');
    spect(108) = mean(yabs(f1_11016:f2_11016));
    
    % 10th octave
    f1_11671 = find(f == 11334, 1, 'first');
    f2_11671 = find(f == 12009, 1, 'last');
    spect(109) = mean(yabs(f1_11671:f2_11671));
    
    f1_12366 = find(f == 12009, 1, 'first');
    f2_12366 = find(f == 12723, 1, 'last');
    spect(110) = mean(yabs(f1_12366:f2_12366));
    
    f1_13102 = find(f == 12723, 1, 'first');
    f2_13102 = find(f == 13481, 1, 'last');
    spect(111) = mean(yabs(f1_13102:f2_13102));
    
    f1_13882 = find(f == 13481, 1, 'first');
    f2_13882 = find(f == 14283, 1, 'last');
    spect(112) = mean(yabs(f1_13882:f2_13882));
    
    f1_14708 = find(f == 14283, 1, 'first');
    f2_14708 = find(f == 15133, 1, 'last');
    spect(113) = mean(yabs(f1_14708:f2_14708));
    
    f1_15584 = find(f == 15133, 1, 'first');
    f2_15584 = find(f == 16034, 1, 'last');
    spect(114) = mean(yabs(f1_15584:f2_15584));
    
    f1_16511 = find(f == 16034, 1, 'first');
    f2_16511 = find(f == 16989, 1, 'last');
    spect(115) = mean(yabs(f1_16511:f2_16511));
    
    f1_17494 = find(f == 16989, 1, 'first');
    f2_17494 = find(f == 18000, 1, 'last');
    spect(116) = mean(yabs(f1_17494:f2_17494));
    
    f1_18535 = find(f == 18000, 1, 'first');
    f2_18535 = find(f == 19071, 1, 'last');
    spect(117) = mean(yabs(f1_18535:f2_18535));

    f1_19639 = find(f == 19071, 1, 'first');
    f2_19639 = find(f == 20206, 1, 'last');
    spect(118) = mean(yabs(f1_19639:f2_19639));
    
    f1_20808 = find(f == 20206, 1, 'first');
    f2_20808 = find(f == 21409, 1, 'last');
    spect(119) = mean(yabs(f1_20808:f2_20808));
    
    f1_22046 = find(f == 21409, 1, 'first');
    f2_22046 = length(f);
    spect(120) = mean(yabs(f1_22046:f2_22046));
     
   freq = [22.7 24 25.4 26.9 28.5 30.2 32 34 36 38.1 40.4 42.8 45.3 48 51 54 57 61 64 68 72 76 81 86 91 96 102 108 114 121 128 136 144 153 162 171 182 192 204 216 229 243 257 272 288 306 324 343 364 385 408 432 458 485 514 545 577 612 648 687 727 771 817 865 917 971 1030 1090 1160 1220 1300 1370 1460 1540 1630 1730 1840 1940 2060 2180 2310 2450 2600 2750 2910 3090 3270 3470 3670 3890 4120 4370 4630 4900 5200 5500 5830 6180 6550 6940 7350 7790 8250 8740 9260 9810 10400 11020 11670 12370 13100 13880 14710 15590 16510 17490 18540 19640 20810 22050]; % Store the evaluated octave bands in a vector
    
end

spect = spect/sum(spect); % Normalize spectrum, the sum of all bands is equal 1

end