function [Lp,Leq,L1,L95] = sound_pressure_level(x2,fs,p0,dBweight,avmode,start_samples,stop_samples)
%INPUTS:
% x2... signal to be analyzed
% fs... sampling rate
% p0... reference sound pressure level, derived via the calibration signal
% dBweight... selected frequency weighting curve
% avmode... time contant for exponential averaging
% start_samples... start position of the analyzation
% stop_samples... stop position of the analyzation
%
%OUTPUTS:
% Lp... time dependent loudness level
% Leq... energy equivalent loudness level
% L1... loudness level that is exceeded in 1% of time
% L95... loudness level that is exceeded in 95% of time

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Author: Rafael Philip LUDWIG, 2014
%%%% Contact: rafael.ludwig@student.tugraz.at
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Function Description: call function time_intervall for selecting signal
% part if start and stop time were entered, create window function, shorten 
% signal that it fits to the window function, multiply signal with window 
% calculate FFT, calculate frequency weighting curves, weight signal with 
% selected frequency curve in the spectral domain, transform it back in the 
% time domain, choose only the real parts, multiply the signal one more 
% time with the window (needed for'DE'-Windowing the signal) 'DE'-Windowing
% of the signal, create audio player for playing the weighted signal, signal
% reduction by calculate linear mean values of respective 1024 samples,
% calculate exponential mean values, derive time dependent sound pressure
% level Lp, via Lp the Leq and the statistic of the sound pressure level 
% is calculated 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Choosing Time Intervall to be evaluated
lenx2 = length(x2); % length of the input signal

[x3] = time_intervall(x2,lenx2,start_samples,stop_samples);

lenx3 = length(x3); 
nfft = 8192;

% Checking if dbweight is flat and skipping the Frequency Domain if Yes
if strcmpi(dBweight,'flat') == 1
    xweight = x3;
    lenx = length(xweight);
    
else 
    %% Create rectangular-window with sine-slope

    n = 0:2*pi/2048:2*pi;
    sine = sin(n);
    startlen = 512;
    startw = sine(1:startlen);
    stopw = fliplr(startw);
    window = [startw ones(1,nfft-2*startlen) stopw];
    lenwindow = length(window);

    max_i = fix((lenx3-startlen)/(nfft-startlen)); % Upper bound for the variable that counts the while-loop below
    max_x = nfft*max_i-512*(max_i-1); % Last sample that will be windowed, the others above that value are cut off
    x = x3(1:max_x);
    x = x.';
    lenx = length(x);
    
    clear x3;
    
    xwin = zeros(1,lenwindow*max_i);
    lenxwin = length(xwin);

    %% Weighting the input file with the created window 
    i = 1;
    while i <= max_i

        if i == 1
            xwin((i-1)*lenwindow+1:i*lenwindow) = window.*x((i-1)*lenwindow+1:i*lenwindow);
        else
            xwin((i-1)*lenwindow+1:i*lenwindow) = window.*x((i-1)*lenwindow-(i-1)*startlen+1:i*lenwindow-(i-1)*startlen); 
        end
        i = i+1;   
    end    
    
    clear x;
    
    %% Fourier Transformation of the input signal

    display('Transforming input signal in the frequency domain');

    nnfft = fix(lenxwin/nfft); % Number of fft's that are required to transform the whole signal in the frequency domain

    xf = zeros(1,lenxwin); % Create empty vector where the Fourier transformed signal is stored
    
    % Transform the signal in the frequency domain, 8192 samples are
    % transformed by one
    for i  = 1:nnfft
        xf(nfft*(i-1)+1:nfft*i) = fft(xwin(nfft*(i-1)+1:nfft*i),nfft);
    end

    clear xwin;
    
    f = fs/2*linspace(0,1,nfft/2); % Create frequency vector
    
    %% Creation of the dB(A), dB(B) and dB(C) weighting curve

    HAf = 12200^2*f.^4./((f.^2+20.6^2).*(f.^2+12200^2).*sqrt(f.^2+107.7^2).*sqrt(f.^2+737.9^2));
    HAf = [HAf fliplr(HAf)];
    HA = 20.*log10(HAf)+2;
    
    HBf = 12200^2*f.^3./((f.^2+20.6^2).*(f.^2+12200.^2).*sqrt(f.^2+158.5.^2));
    HBf = [HBf fliplr(HBf)];
    HB = 20.*log10(HBf)+0.17;

    HCf = 12200^2*f.^2./((f.^2+20.6^2).*(f.^2+12200^2));
    HCf = [HCf fliplr(HCf)];
    HC = 20*log10(HCf)+0.06;

    %% Selecting one weighting curve

    if strcmpi(dBweight,'dB(A)') == 1
       H = HA;
       Hn = 10.^(H/20);
    elseif strcmpi(dBweight,'dB(B)') == 1
       H = HB;
       Hn = 10.^(H/20);
    elseif strcmpi(dBweight,'dB(C)') == 1
       H = HC;
       Hn = 10.^(H/20);
    end

    %% Weighting the input signal with the selected weighting curve

    display('Weighting the signal with the selected frequency curve');

    xfweight = zeros(1,lenxwin);

    for i = 1:nnfft   
          xfweight(nfft*(i-1)+1:nfft*i) = xf(nfft*(i-1)+1:nfft*i).*Hn;
    end
    
    clear xf;

    %% Inverse Fourier Transform of the input signal, 8192 samples are
    %  transformed by one

    display('Inverse Fourier Transform of the weighted input signal');
    
    xweightwin = zeros(1,lenxwin);
    
    for i  = 1:nnfft 
        xweightwin(nfft*(i-1)+1:nfft*i) = ifft(xfweight(nfft*(i-1)+1:nfft*i),nfft);
    end
 
    clear xfweight;
    
    xweightwin = real(xweightwin); % Only real part of the inverse transformed signal is chosen for further calculations
    
    %% Multiplying the weighted signal one more time with the window so 
    % that the non-windowed signal x can be recomposed (i.e (sinx)^2+(cosx)^2=1) 
    
    xweightwinwin = zeros(1,lenxwin);
    
    for i = 1:nnfft
        xweightwinwin((i-1)*lenwindow+1:i*lenwindow) = xweightwin((i-1)*lenwindow+1:i*lenwindow).*window;
    end
    
    lenxweightwinwin = length(xweightwinwin);
    
    clear xweightwin;
    
    %% 'De-Windowing' of the signal
    xweight = zeros(1,lenx);

    i = 1;
    while i*lenwindow <= lenxweightwinwin
        if i == 1
            xweight(1:lenwindow) = xweightwinwin(1:lenwindow);
        else
            xweight((i-1)*lenwindow -(i-1)*startlen+1:i*lenwindow-(i-1)*startlen) = xweightwinwin((i-1)*lenwindow+1:i*lenwindow) + xweight((i-1)*lenwindow -(i-1)*startlen+1:i*lenwindow-(i-1)*startlen);
        end
        i = i+1;
    end
    
    clear xweightwinwin;
    
end

player = audioplayer(xweight,fs); % Create audio player for playing frequency weighted file

%% Choose time constant for mean value calculation
% fast = 125 ms; slow = 1 s; peak = 35 ms, 1.5s

fast = 0.125;
slow = 1;
impulse = 0.035;

if strcmpi(avmode,'fast') == 1
    avtime = fast;
elseif strcmpi(avmode,'slow') == 1
    avtime = slow;    
else
    avtime = impulse;
    avtime2 = 1.5; 
end    
    
%% Calculation of the linear mean values, length: 1024 samples

lenlinmean = 1024; % The RMS value of each 1024 samples is derived
lenlinmean1 = fix(lenx/lenlinmean); % Number of RMS value calculations

display('Calculating the linear mean value per 1024 samples');

xlinmean = zeros(1,lenlinmean1+1); % Empty vector where RMS values are stored

for i = 1:lenlinmean1
    xlinmean(i) = sqrt((1/lenlinmean)*sum((xweight(lenlinmean*(i-1)+1:lenlinmean*i).^2)));
end

lenxlinmean = length(xlinmean);

 %% Calculation of the exponential mean values

display('Calculating the exponential mean value per sample');

xlinmean(lenxlinmean+1) = 0; % For exponential mean value calculation one extra sample is required
xexpmean = zeros(1,lenxlinmean+1); % Default vector where exponential mean values are stored

% Check which time constant is selected
if strcmpi(avmode,'impulse') == 1 % Impulse-weighting

    for i = 1:lenxlinmean
        % Calculation of the weighting factors for the first and second
        % sample
        if xlinmean(i+1) > xexpmean(i) % Second sample is larger than first one (increase), g1 = 35ms 
            g1 = exp(-lenlinmean/(fs*avtime));
            g2 = 1-g1;
        else % First sample is larger than second one (decrease), g1 = 1.5s
            g1 = exp(-lenlinmean/(fs*avtime2));
            g2 = 1-g1;
        end
        
        xexpmean(i+1) = g1*xexpmean(i) + g2*xlinmean(i+1);
    end
    
else % Fast or slow-weighting
    % Calculation of the weighting factors for the first and second sample
    g1 = exp(-lenlinmean/(fs*avtime));
    g2 = 1-g1;

    for i = 1:lenxlinmean
        xexpmean(i+1) = g1*xexpmean(i) + g2*xlinmean(i+1);
    end
   
end

lenxexpmean = length(xexpmean);
xexpmean = xexpmean(2:lenxexpmean); % Delete the first sample which is zero
lenxexpmean = length(xexpmean); % New vector length

% Set values smaller than p0 to p0 to avoid negative dB values
for i = 1:lenxexpmean
    if xexpmean(i) < p0
       xexpmean(i) = p0;    
    end    
end


clear xlinmean;

%% Calculation of the sound pressure leves

display('Calculating the Sound Pressure Levels');

%% Lp

Lp = 20.*log10(xexpmean./p0); % Deriving Lp
Lp = round(Lp*10)/10; % Round Lp to one decimal

lenLp = length(Lp); % Number of samples

clear xexpmean;

%% Leq

Leq = 10*log10((1/lenLp)*sum(10.^(Lp/10))); % Deriving Leq
Leq = round(Leq*10)/10; % Round it to one decimal

Lpmax = max(Lp);
Lpmin = min(Lp);

%% Calculation of L1 via counting the values in the histogram of Lp

lenhistogram = (Lpmin:0.1:Lpmax);
histogram = hist(Lp,lenhistogram); % Creating a histogram of Lp with stepsize 0.1 dB

indL1 = round(lenLp*0.99); % Position from zero away in the histogram where the value L1 is situated 
sum1 = 0;

for i1 = 1:length(lenhistogram) % Find the index in the histogram where L1 is stored
    if sum1 <= indL1  
        sum1 = sum1 + histogram(i1);
    else 
        break 
    end    
end

L1 = lenhistogram(i1); % The index i1 points to the value of L1 in the vector lenhistogram
L1 = round(L1*10)/10; % Round L1 to one decimal

%% Calculation of L95 via counting the values in the histogram of Lp

indL95 = round(lenLp*0.05); % Position from zero away in the histogram where the value LP95 is situated
sum95 = 0;

for i95 = 1:length(lenhistogram) % Find the index in the histogram where L95 is stored
    if sum95 <= indL95  
        sum95 = sum95 + histogram(i95);
    else 
        break 
    end    
end

L95 = lenhistogram(i95); % The index i1 points to the value of L95 in the vector lenhistogram
L95 = round(L95*10)/10; % Round L95 to one decimal

%% Calculation of L0.1 via counting the values in the histogram of Lp

indL0_1 = round(lenLp*0.999); % Position from zero away in the histogram where the value LP0.1 is situated
sum0_1 = 0;

for i0_1 = 1:length(lenhistogram) % Find the index in the histogram where L0.1 is stored
    if sum0_1 <= indL0_1  
        sum0_1 = sum0_1 + histogram(i0_1);
    else 
        break 
    end    
end

L0_1 = lenhistogram(i0_1); % The index i0.1 points to the value of L0.1 in the vector lenhistogram
L0_1 = round(L0_1*10)/10; % Round L0.1 to one decimal

%% Calculation of L10 via counting the values in the histogram of Lp

indL10 = round(lenLp*0.9); % Position from zero away in the histogram where the value LP10 is situated
sum10 = 0;

for i10 = 1:length(lenhistogram) % Find the index in the histogram where L10 is stored
    if sum10 <= indL10  
        sum10 = sum10 + histogram(i10);
    else 
        break 
    end    
end

L10 = lenhistogram(i10); % The index i10 points to the value of L10 in the vector lenhistogram
L10 = round(L10*10)/10; % Round L10 to one decimal

%% Calculation of L33.3 via counting the values in the histogram of Lp

indL33_3 = round(lenLp*0.667); % Position from zero away in the histogram where the value LP33.3 is situated
sum33_3 = 0;

for i33_3 = 1:length(lenhistogram) % Find the index in the histogram where L33.3 is stored
    if sum33_3 <= indL33_3  
        sum33_3 = sum33_3 + histogram(i33_3);
    else 
        break 
    end    
end

L33_3 = lenhistogram(i33_3); % The index i33_3 points to the value of L33_3 in the vector lenhistogram
L33_3 = round(L33_3*10)/10; % Round L33_3 to one decimal

%% Calculation of L50 via counting the values in the histogram of Lp

indL50 = round(lenLp*0.5); % Position from zero away in the histogram where the value LP50 is situated
sum50 = 0;

for i50 = 1:length(lenhistogram) % Find the index in the histogram where L50 is stored
    if sum50 <= indL50  
        sum50 = sum50 + histogram(i50);
    else 
        break 
    end    
end

L50 = lenhistogram(i50); % The index i50 points to the value of L50 in the vector lenhistogram
L50 = round(L50*10)/10; % Round L50 to one decimal

%% Calculation of L66.6 via counting the values in the histogram of Lp

indL66_6 = round(lenLp*0.334); % Position from zero away in the histogram where the value LP66_6 is situated
sum66_6 = 0;

for i66_6 = 1:length(lenhistogram) % Find the index in the histogram where L66.6 is stored
    if sum66_6 <= indL66_6  
        sum66_6 = sum66_6 + histogram(i66_6);
    else 
        break 
    end    
end

L66_6 = lenhistogram(i66_6); % The index i66_6 points to the value of L66.6 in the vector lenhistogram
L66_6 = round(L66_6*10)/10; % Round L66.6 to one decimal

%% Calculation of L90 via counting the values in the histogram of Lp

indL90 = round(lenLp*0.1); % Position from zero away in the histogram where the value LP90 is situated
sum90 = 0;

for i90 = 1:length(lenhistogram) % Find the index in the histogram where L90 is stored
    if sum90 <= indL90  
        sum90 = sum90 + histogram(i90);
    else 
        break 
    end    
end

L90 = lenhistogram(i90); % The index i90 points to the value of L90 in the vector lenhistogram
L90 = round(L90*10)/10; % Round L90 to one decimal

%% Calculation of L99 via counting the values in the histogram of Lp

indL99 = round(lenLp*0.01); % Position from zero away in the histogram where the value LP99 is situated
sum99 = 0;

for i99 = 1:length(lenhistogram) % Find the index in the histogram where L99 is stored
    if sum99 <= indL99  
        sum99 = sum99 + histogram(i99);
    else 
        break 
    end    
end

L99 = lenhistogram(i99); % The index i99 points to the value of L99 in the vector lenhistogram
L99 = round(L99*10)/10; % Round L99 to one decimal

%% Calculation of L99.9 via counting the values in the histogram of Lp

indL99_9 = round(lenLp*0.001); % Position from zero away in the histogram where the value LP99.9 is situated
sum99_9 = 0;

for i99_9 = 1:length(lenhistogram) % Find the index in the histogram where L99.9 is stored
    if sum99_9 <= indL99_9  
        sum99_9 = sum99_9 + histogram(i99_9);
    else 
        break 
    end    
end

L99_9 = lenhistogram(i99_9); % The index i99_9 points to the value of L99.9 in the vector lenhistogram
L99_9 = round(L99_9*10)/10; % Round L99.9 to one decimal

%% Store analyzed data in the workspace 

assignin('base','lenlinmean',lenlinmean);
assignin('base','xweight',xweight);
assignin('base','start_samples',start_samples);
assignin('base','stop_samples',stop_samples);
assignin('base','player',player);
assignin('base','lenhistogram',lenhistogram);
assignin('base','L0_1',L0_1);
assignin('base','L10',L10);
assignin('base','L33_3',L33_3);
assignin('base','L50',L50);
assignin('base','L66_6',L66_6);
assignin('base','L90',L90);
assignin('base','L99',L99);
assignin('base','L99_9',L99_9);

display('Finished')

end
